==> adminer_4.6.3.orig.tar.gz: adminer-4.6.3/adminer/lang/zh-tw.inc.php <==
<?php
$translations = array(
	'Login' => '登入',
	'Logout successful.' => '成功登出。',
	'Invalid credentials.' => '無效的憑證。',
	'Server' => '伺服器',
	'Username' => '帳號',
	'Password' => '密碼',
	'Select database' => '選擇資料庫',
	'Invalid database.' => '無效的資料庫。',
	'Table has been altered.' => '資料表已修改。',
	'Table has been created.' => '資料表已修改。',
	'Alter table' => '修改資料表',
	'Create table' => '建立資料表',
	'Table name' => '資料表名稱',
	'engine' => '引擎',
	'collation' => '校對',
	'Column name' => '列名',
	'Type' => '類型',
	'Length' => '長度',
	'Auto Increment' => '自動遞增',
	'Options' => '選項',
	'Save' => '儲存',
	'Drop' => '刪除',
	'Database has been dropped.' => '資料庫已刪除。',
	'Database has been created.' => '已建立資料庫。',
	'Database has been renamed.' => '已重新命名資料庫。',
	'Database has been altered.' => '已修改資料庫。',
	'Alter database' => '修改資料庫',
	'Create database' => '建立資料庫',
	'SQL command' => 'SQL命令',
	'Logout' => '登出',
	'database' => '資料庫',
	'Use' => '使用',
	'No tables.' => '沒有資料表。',
	'select' => '選擇',
	'Item has been updated.' => '已更新項目。',
	'Item%s has been inserted.' => '已新增項目%s。',
	'Edit' => '編輯',
	'Insert' => '新增',
	'Save and insert next' => '儲存並新增下一筆',
	'Delete' => '刪除',
	'Database' => '資料庫',
	'Routines' => '程序',
	'Indexes have been altered.' => '已修改索引。',
	'Indexes' => '索引',
	'Alter indexes' => '修改索引',
	'Add next' => '新增下一筆',
	'Language' => '語言',
	'Select' => '選擇',
	'New item' => '新增項目',
	'Search' => '搜尋',
	'Sort' => '排序',
	'descending' => '降冪(遞減)',
	'Limit' => '限定',
	'No rows.' => '沒有行。',
	'Action' => '動作',
	'edit' => '編輯',
	'Page' => '頁',
	'Query executed OK, %d row(s) affected.' => '執行查詢OK，%d行受影響',
	'Error in query' => '查詢發生錯誤',
	'Execute' => '執行',
	'Table' => '資料表',
	'Foreign keys' => '外來鍵',
	'Triggers' => '觸發器',
	'View' => '檢視表',
	'Unable to select the table' => '無法選擇該資料表',
	'Invalid CSRF token. Send the form again.' => '無效的 CSRF token。請重新發送表單。',
	'Comment' => '註解',
	'Default values' => '預設值',
	'%d byte(s)' => '%d byte(s)',
	'No commands to execute.' => '沒有命令可執行。',
	'Unable to upload a file.' => '無法上傳檔案。',
	'File upload' => '檔案上傳',
	'File uploads are disabled.' => '檔案上傳已經被停用。',
	'Routine has been called, %d row(s) affected.' => '程序已被執行，%d行被影響',
	'Call' => '呼叫',
	'No extension' => '無擴充模組',
	'None of the supported PHP extensions (%s) are available.' => '沒有任何支援的PHP擴充模組（%s）。',
	'Session support must be enabled.' => 'Session 必須被啟用。',
	'Session expired, please login again.' => 'Session 已過期，請重新登入。',
	'Text length' => 'Text 長度',
	'Foreign key has been dropped.' => '已刪除外來鍵。',
	'Foreign key has been altered.' => '已修改外來鍵。',
	'Foreign key has been created.' => '已建立外來鍵。',
	'Foreign key' => '外來鍵',
	'Target table' => '目標資料表',
	'Change' => '修改',
	'Source' => '來源',
	'Target' => '目標',
	'Add column' => '新增資料列',
	'Alter' => '修改',
	'Add foreign key' => '新增外來鍵',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => '索引類型',
	'Column (length)' => '列（長度）',
	'View has been dropped.' => '已刪除檢視表。',
	'View has been altered.' => '已修改檢視表。',
	'View has been created.' => '已建立檢視表。',
	'Alter view' => '修改檢視表',
	'Create view' => '建立檢視表',
	'Name' => '名稱',
	'Process list' => '處理程序列表',
	'%d process(es) have been killed.' => '%d 個 Process(es) 被終止',
	'Kill' => '終止',
	'Parameter name' => '參數名稱',
	'Database schema' => '資料庫架構',
	'Create procedure' => '建立預存程序',
	'Create function' => '建立函數',
	'Routine has been dropped.' => '已刪除程序。',
	'Routine has been altered.' => '已修改子程序。',
	'Routine has been created.' => '已建立子程序。',
	'Alter function' => '修改函數',
	'Alter procedure' => '修改過程',
	'Return type' => '回傳類型',
	'Add trigger' => '建立觸發器',
	'Trigger has been dropped.' => '已刪除觸發器。',
	'Trigger has been altered.' => '已修改觸發器。',
	'Trigger has been created.' => '已建立觸發器。',
	'Alter trigger' => '修改觸發器',
	'Create trigger' => '建立觸發器',
	'Time' => '時間',
	'Event' => '事件',
	'%s version: %s through PHP extension %s' => '%s版本：%s 透過PHP擴充模組 %s',
	'%d row(s)' => '%d行',
	'Remove' => '移除',
	'Are you sure?' => '你確定嗎？',
	'Privileges' => '權限',
	'Create user' => '建立使用者',
	'User has been dropped.' => '已刪除使用者。',
	'User has been altered.' => '已修改使用者。',
	'User has been created.' => '已建立使用者。',
	'Hashed' => 'Hashed',
	'Column' => '列',
	'Routine' => '程序',
	'Grant' => '授權',
	'Revoke' => '廢除',
	'Logged as: %s' => '登錄為：%s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST 資料太大。減少資料或者增加 %s 的設定值。',
	'Move up' => '上移',
	'Move down' => '下移',
	'Export' => '匯出',
	'Tables' => '資料表',
	'Data' => '資料',
	'Output' => '輸出',
	'open' => '打開',
	'save' => '儲存',
	'Format' => '格式',
	'Functions' => '函數',
	'Aggregation' => '集合',
	'Event has been dropped.' => '已刪除事件。',
	'Event has been altered.' => '已修改事件。',
	'Event has been created.' => '已建立事件。',
	'Alter event' => '修改事件',
	'Create event' => '建立事件',
	'Start' => '開始',
	'End' => '結束',
	'Every' => '每',
	'Status' => '狀態',
	'On completion preserve' => '在完成後儲存',
	'Events' => '事件',
	'Schedule' => '排程',
	'At given time' => '在指定時間',
	'Tables have been truncated.' => '已清空資料表。',
	'Tables have been moved.' => '已轉移資料表。',
	'Tables and views' => '資料表和檢視表',
	'Engine' => '引擎',
	'Collation' => '校對',
	'Data Length' => '資料長度',
	'Index Length' => '索引長度',
	'Data Free' => '資料空閒',
	'Rows' => '行數',
	',' => ',',
	'0123456789' => '0123456789',
	'Analyze' => '分析',
	'Optimize' => '最佳化',
	'Check' => '檢查',
	'Repair' => '修復',
	'Truncate' => '清空',
	'Move to other database' => '轉移到其它資料庫',
	'Move' => '轉移',
	'Save and continue edit' => '儲存並繼續編輯',
	'original' => '原始',
	'%d item(s) have been affected.' => '%d個項目受到影響。',
	'Whole result' => '所有結果',
	'Tables have been dropped.' => '已經將資料表刪除。',
	'Clone' => '複製',
	'Maximum number of allowed fields exceeded. Please increase %s.' => '超過允許的字段數量的最大值。請增加%s。',
	'Partition by' => '分區類型',
	'Partitions' => '分區',
	'Partition name' => '分區名稱',
	'Values' => '值',
	'%d row(s) have been imported.' => '已匯入%d行。',
	'anywhere' => '任意位置',
	'Import' => '匯入',
	'Stop on error' => '出錯時停止',
	'%.3f s' => '%.3f秒',
	'$1-$3-$5' => '$1.$3.$5',
	'[yyyy]-mm-dd' => '[yyyy].mm.dd',
	'History' => '紀錄',
	'Variables' => '變數',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => '來源列和目標列必須具有相同的資料類型，在目標列上必須有一個索引並且引用的資料必須存在。',
	'Relations' => '關聯',
	'Run file' => '執行檔案',
	'Clear' => '清除',
	'Maximum allowed file size is %sB.' => '允許的檔案上限大小為%sB',
	'Numbers' => '數字',
	'Date and time' => '日期時間',
	'Strings' => '字串',
	'Binary' => '二進位',
	'Lists' => '列表',
	'Editor' => '編輯器',
	'E-mail' => '電子郵件',
	'From' => '來自',
	'Subject' => '主旨',
	'Send' => '寄出',
	'%d e-mail(s) have been sent.' => '已寄出 %d 封郵件。',
	'Webserver file %s' => '網頁伺服器檔案 %s',
	'File does not exist.' => '檔案不存在',
	'Item has been deleted.' => '該項目已被刪除',
	'%d in total' => '總共 %d 個',
	'Permanent login' => '永久登入',
	'Table has been dropped.' => '已經刪除資料表。',
	'Databases have been dropped.' => '資料庫已刪除。',
	'Search data in tables' => '在資料庫搜尋',
	'Schema' => '資料表結構',
	'Alter schema' => '修改資料表結構',
	'Create schema' => '建立資料表結構',
	'Schema has been dropped.' => '已刪除資料表結構。',
	'Schema has been created.' => '已建立資料表結構。',
	'Schema has been altered.' => '已修改資料表結構。',
	'Sequences' => '序列',
	'Create sequence' => '建立序列',
	'Alter sequence' => '修改序列',
	'Sequence has been dropped.' => '已刪除序列。',
	'Sequence has been created.' => '已建立序列。',
	'Sequence has been altered.' => '已修改序列。',
	'User types' => '使用者類型',
	'Create type' => '建立類型',
	'Alter type' => '修改類型',
	'Type has been dropped.' => '已刪除類型。',
	'Type has been created.' => '已建立類型。',
	'Use edit link to modify this value.' => '使用編輯連結來修改。',
	'last' => '最後一頁',
	'From server' => '從伺服器',
	'System' => '資料庫系統',
	'Select data' => '選擇資料',
	'Show structure' => '顯示結構',
	'empty' => '空值',
	'Network' => '網路',
	'Geometry' => '幾何',
	'File exists.' => '檔案已存在。',
	'Attachments' => '附件',
	'%d query(s) executed OK.' => '已順利執行 %d 個查詢。',
	'Show only errors' => '僅顯示錯誤訊息',
	'Refresh' => '重新載入',
	'Invalid schema.' => '無效的資料表結構。',
	'Please use one of the extensions %s.' => '請使用下列其中一個擴充模組 %s。',
	'now' => '現在',
	'ltr' => 'ltr',
	'Tables have been copied.' => '資料表已經複製',
	'Copy' => '複製',
	'Permanent link' => '永久連結',
	'Edit all' => '編輯全部',
	'HH:MM:SS' => 'HH:MM:SS',
);

==> adminer_4.7.0.orig.tar.gz: adminer-4.7.0/adminer/lang/zh-tw.inc.php <==
<?php
$translations = array(
	'Login' => '登入',
	'Logout successful.' => '成功登出。',
	'Invalid credentials.' => '無效的憑證。',
	'Server' => '伺服器',
	'Username' => '帳號',
	'Password' => '密碼',
	'Select database' => '選擇資料庫',
	'Invalid database.' => '無效的資料庫。',
	'Table has been altered.' => '資料表已修改。',
	'Table has been created.' => '資料表已建立。',
	'Alter table' => '修改資料表',
	'Create table' => '建立資料表',
	'Table name' => '資料表名稱',
	'engine' => '引擎',
	'collation' => '校對',
	'Column name' => '欄位名稱',
	'Type' => '類型',
	'Length' => '長度',
	'Auto Increment' => '自動遞增',
	'Options' => '選項',
	'Save' => '儲存',
	'Drop' => '刪除',
	'Database has been dropped.' => '資料庫已刪除。',
	'Database has been created.' => '已建立資料庫。',
	'Database has been renamed.' => '已重新命名資料庫。',
	'Database has been altered.' => '已修改資料庫。',
	'Alter database' => '修改資料庫',
	'Create database' => '建立資料庫',
	'SQL command' => 'SQL 命令',
	'Logout' => '登出',
	'database' => '資料庫',
	'Use' => '使用',
	'No tables.' => '沒有資料表。',
	'select' => '選擇',
	'Item has been updated.' => '已更新項目。',
	'Item%s has been inserted.' => '已新增項目 %s。',
	'Edit' => '編輯',
	'Insert' => '新增',
	'Save and insert next' => '儲存並新增下一筆',
	'Delete' => '刪除',
	'Database' => '資料庫',
	'Routines' => '程序',
	'Indexes have been altered.' => '已修改索引。',
	'Indexes' => '索引',
	'Alter indexes' => '修改索引',
	'Add next' => '新增下一筆',
	'Language' => '語言',
	'Select' => '選擇',
	'New item' => '新增項目',
	'Search' => '搜尋',
	'Sort' => '排序',
	'descending' => '降冪 (遞減)',
	'Limit' => '限定',
	'No rows.' => '沒有資料行。',
	'Action' => '動作',
	'edit' => '編輯',
	'Page' => '頁',
	'Query executed OK, %d row(s) affected.' => '執行查詢 OK，%d 行受影響。',
	'Error in query' => '查詢發生錯誤',
	'Execute' => '執行',
	'Table' => '資料表',
	'Foreign keys' => '外來鍵',
	'Triggers' => '觸發器',
	'View' => '檢視表',
	'Unable to select the table' => '無法選擇該資料表',
	'Invalid CSRF token. Send the form again.' => '無效的 CSRF token。請重新發送表單。',
	'Comment' => '註解',
	'Default values' => '預設值',
	'%d byte(s)' => '%d byte(s)',
	'No commands to execute.' => '沒有命令可執行。',
	'Unable to upload a file.' => '無法上傳檔案。',
	'File upload' => '檔案上傳',
	'File uploads are disabled.' => '檔案上傳已經被停用。',
	'Routine has been called, %d row(s) affected.' => '程序已被執行，%d 行被影響',
	'Call' => '呼叫',
	'No extension' => '無擴充模組',
	'None of the supported PHP extensions (%s) are available.' => '沒有任何支援的 PHP 擴充模組（%s）。',
	'Session support must be enabled.' => 'Session 必須被啟用。',
	'Session expired, please login again.' => 'Session 已過期，請重新登入。',
	'Text length' => 'Text 長度',
	'Foreign key has been dropped.' => '已刪除外來鍵。',
	'Foreign key has been altered.' => '已修改外來鍵。',
	'Foreign key has been created.' => '已建立外來鍵。',
	'Foreign key' => '外來鍵',
	'Target table' => '目標資料表',
	'Change' => '變更',
	'Source' => '來源',
	'Target' => '目標',
	'Add column' => '新增欄位',
	'Alter' => '修改',
	'Add foreign key' => '新增外來鍵',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => '索引類型',
	'Column (length)' => '欄位（長度）',
	'View has been dropped.' => '已刪除檢視表。',
	'View has been altered.' => '已修改檢視表。',
	'View has been created.' => '已建立檢視表。',
	'Alter view' => '修改檢視表',
	'Create view' => '建立檢視表',
	'Name' => '名稱',
	'Process list' => '處理程序列表',
	'%d process(es) have been killed.' => '%d 個 Process(es) 被終止',
	'Kill' => '終止',
	'Parameter name' => '參數名稱',
	'Database schema' => '資料庫結構',
	'Create procedure' => '建立預存程序',
	'Create function' => '建立函式',
	'Routine has been dropped.' => '已刪除程序。',
	'Routine has been altered.' => '已修改子程序。',
	'Routine has been created.' => '已建立子程序。',
	'Alter function' => '修改函式',
	'Alter procedure' => '修改預存程序',
	'Return type' => '回傳類型',
	'Add trigger' => '建立觸發器',
	'Trigger has been dropped.' => '已刪除觸發器。',
	'Trigger has been altered.' => '已修改觸發器。',
	'Trigger has been created.' => '已建立觸發器。',
	'Alter trigger' => '修改觸發器',
	'Create trigger' => '建立觸發器',
	'Time' => '時間',
	'Event' => '事件',
	'%s version: %s through PHP extension %s' => '%s 版本：%s 透過 PHP 擴充模組 %s',
	'%d row(s)' => '%d 行',
	'Remove' => '移除',
	'Are you sure?' => '你確定嗎？',
	'Privileges' => '權限',
	'Create user' => '建立使用者',
	'User has been dropped.' => '已刪除使用者。',
	'User has been altered.' => '已修改使用者。',
	'User has been created.' => '已建立使用者。',
	'Hashed' => 'Hashed',
	'Column' => '欄位',
	'Routine' => '程序',
	'Grant' => '授權',
	'Revoke' => '廢除',
	'Logged as: %s' => '登錄為： %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST 資料太大。減少資料或者增加 %s 的設定值。',
	'Move up' => '上移',
	'Move down' => '下移',
	'Export' => '匯出',
	'Tables' => '資料表',
	'Data' => '資料',
	'Output' => '輸出',
	'open' => '打開',
	'save' => '儲存',
	'Format' => '格式',
	'Functions' => '函式',
	'Aggregation' => '集合',
	'Event has been dropped.' => '已刪除事件。',
	'Event has been altered.' => '已修改事件。',
	'Event has been created.' => '已建立事件。',
	'Alter event' => '修改事件',
	'Create event' => '建立事件',
	'Start' => '開始',
	'End' => '結束',
	'Every' => '每',
	'Status' => '狀態',
	'On completion preserve' => '在完成後儲存',
	'Events' => '事件',
	'Schedule' => '排程',
	'At given time' => '在指定時間',
	'Tables have been truncated.' => '已清空資料表。',
	'Tables have been moved.' => '已轉移資料表。',
	'Tables and views' => '資料表和檢視表',
	'Engine' => '引擎',
	'Collation' => '校對',
	'Data Length' => '資料長度',
	'Index Length' => '索引長度',
	'Data Free' => '資料空閒',
	'Rows' => '行數',
	',' => ',',
	'0123456789' => '0123456789',
	'Analyze' => '分析',
	'Optimize' => '最佳化',
	'Check' => '檢查',
	'Repair' => '修復',
	'Truncate' => '清空',
	'Move to other database' => '轉移到其它資料庫',
	'Move' => '轉移',
	'Save and continue edit' => '儲存並繼續編輯',
	'original' => '原始',
	'%d item(s) have been affected.' => '%d 個項目受到影響。',
	'Whole result' => '所有結果',
	'Tables have been dropped.' => '已經將資料表刪除。',
	'Clone' => '複製',
	'Maximum number of allowed fields exceeded. Please increase %s.' => '超過允許的字段數量的最大值。請增加 %s。',
	'Partition by' => '分區類型',
	'Partitions' => '分區',
	'Partition name' => '分區名稱',
	'Values' => '值',
	'%d row(s) have been imported.' => '已匯入 %d 行。',
	'anywhere' => '任意位置',
	'Import' => '匯入',
	'Stop on error' => '出錯時停止',
	'%.3f s' => '%.3f 秒',
	'$1-$3-$5' => '$1.$3.$5',
	'[yyyy]-mm-dd' => '[yyyy].mm.dd',
	'History' => '紀錄',
	'Variables' => '變數',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => '來源列和目標列必須具有相同的資料類型，在目標列上必須有一個索引並且引用的資料必須存在。',
	'Relations' => '關聯',
	'Run file' => '執行檔案',
	'Clear' => '清除',
	'Maximum allowed file size is %sB.' => '允許的檔案上限大小為 %sB',
	'Numbers' => '數字',
	'Date and time' => '日期時間',
	'Strings' => '字串',
	'Binary' => '二進位',
	'Lists' => '列表',
	'Editor' => '編輯器',
	'E-mail' => '電子郵件',
	'From' => '來自',
	'Subject' => '主旨',
	'Send' => '寄出',
	'%d e-mail(s) have been sent.' => '已寄出 %d 封郵件。',
	'Webserver file %s' => '網頁伺服器檔案 %s',
	'File does not exist.' => '檔案不存在',
	'Item has been deleted.' => '該項目已被刪除',
	'%d in total' => '總共 %d 個',
	'Permanent login' => '永久登入',
	'Table has been dropped.' => '已經刪除資料表。',
	'Databases have been dropped.' => '資料庫已刪除。',
	'Search data in tables' => '在資料庫搜尋',
	'Schema' => '資料表結構',
	'Alter schema' => '修改資料表結構',
	'Create schema' => '建立資料表結構',
	'Schema has been dropped.' => '已刪除資料表結構。',
	'Schema has been created.' => '已建立資料表結構。',
	'Schema has been altered.' => '已修改資料表結構。',
	'Sequences' => '序列',
	'Create sequence' => '建立序列',
	'Alter sequence' => '修改序列',
	'Sequence has been dropped.' => '已刪除序列。',
	'Sequence has been created.' => '已建立序列。',
	'Sequence has been altered.' => '已修改序列。',
	'User types' => '使用者類型',
	'Create type' => '建立類型',
	'Alter type' => '修改類型',
	'Type has been dropped.' => '已刪除類型。',
	'Type has been created.' => '已建立類型。',
	'Use edit link to modify this value.' => '使用編輯連結來修改。',
	'last' => '最後一頁',
	'From server' => '從伺服器',
	'System' => '資料庫系統',
	'Select data' => '選擇資料',
	'Show structure' => '顯示結構',
	'empty' => '空值',
	'Network' => '網路',
	'Geometry' => '幾何',
	'File exists.' => '檔案已存在。',
	'Attachments' => '附件',
	'%d query(s) executed OK.' => '已順利執行 %d 個查詢。',
	'Show only errors' => '僅顯示錯誤訊息',
	'Refresh' => '重新載入',
	'Invalid schema.' => '無效的資料表結構。',
	'Please use one of the extensions %s.' => '請使用下列其中一個擴充模組 %s。',
	'now' => '現在',
	'ltr' => 'ltr',
	'Tables have been copied.' => '資料表已經複製',
	'Copy' => '複製',
	'Permanent link' => '永久連結',
	'Edit all' => '編輯全部',
	'HH:MM:SS' => 'HH:MM:SS',
);
